@@ -35,7 +35,6 @@ def serialize_output(data: Any) -> Any:
         )  # Use Pydantic's built-in JSON serialization
     elif isinstance(data, list):
         return [serialize_output(item) for item in data]
-    # Removed dataclass handling as API uses Pydantic models primarily
     elif isinstance(data, dict):
         # Serialize dictionary values
         return {k: serialize_output(v) for k, v in data.items()}
@@ -177,7 +176,15 @@ def cli(ctx, base_url, api_key, verify_ssl, verbose, disable_response_validation
     # --- Configure Logger ---
     log_level = "DEBUG" if verbose else "INFO"
     logger.remove()  # Remove default handler
-    logger.add(sys.stderr, level=log_level)
+    if verbose:
+        logger.add(
+            sys.stderr,
+            level=log_level,
+            format="<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | <level>{level: <8}</level> | <cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>",
+        )
+        logger.debug("Verbose logging enabled with detailed format.")
+    else:
+        logger.add(sys.stderr, level=log_level) # Default format for INFO
     logger.debug("Logger configured for level: {}", log_level)
     logger.debug("CLI context initialized.")
 
@@ -345,7 +352,6 @@ def create_click_command(
     full_help = docstring
 
     # tweak the whitespaces in the full help:
-    # full_help = full_help.replace("\n", "\n\n").replace("\n                ", " ")
     full_help = full_help.replace("\n               ", " ")
     full_help = full_help.replace("\n", "\n\n")
 
@@ -452,7 +458,6 @@ def create_click_command(
         elif isinstance(click_type, click.Choice):
              param_help += f" (Choices: {', '.join(click_type.choices)})"
 
-        # Standard parameter handling (no special '--data' mapping anymore)
         click_required = is_required_in_sig and default_value is None and not is_flag
 
         # Add the Click Option
