@@ -1,4 +1,5 @@
 import pytest
+from loguru import logger
 import os
 import subprocess
 import random
@@ -24,23 +25,23 @@ def test_get_all_bookmarks_paginated(karakeep_client: KarakeepAPI):
         ), "Response should be PaginatedBookmarks model"
         assert isinstance(page1.bookmarks, list), "Bookmarks attribute should be a list"
         assert len(page1.bookmarks) <= 2, "Should return at most 'limit' bookmarks"
-        print(f"✓ Retrieved first page with {len(page1.bookmarks)} bookmarks.")
+        logger.info(f"✓ Retrieved first page with {len(page1.bookmarks)} bookmarks.")
 
         # If there's a next cursor, get the next page
         if page1.nextCursor:
-            print(f"  Attempting to fetch next page with cursor: {page1.nextCursor}")
+            logger.info(f"  Attempting to fetch next page with cursor: {page1.nextCursor}")
             page2 = karakeep_client.get_all_bookmarks(limit=2, cursor=page1.nextCursor)
             assert isinstance(page2, datatypes.PaginatedBookmarks)
             assert isinstance(page2.bookmarks, list)
             assert len(page2.bookmarks) <= 2
-            print(f"✓ Retrieved second page with {len(page2.bookmarks)} bookmarks.")
+            logger.info(f"✓ Retrieved second page with {len(page2.bookmarks)} bookmarks.")
             # Ensure bookmarks are different from page 1 (simple check)
             if page1.bookmarks and page2.bookmarks:
                 assert (
                     page1.bookmarks[0].id != page2.bookmarks[0].id
                 ), "Bookmarks on page 1 and 2 should differ"
         else:
-            print("  No next cursor found, pagination test ends.")
+            logger.info("  No next cursor found, pagination test ends.")
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during paginated bookmark retrieval: {e}")
@@ -51,21 +52,21 @@ def test_get_all_bookmarks_paginated(karakeep_client: KarakeepAPI):
 
     # --- Add CLI call ---
     try:
-        print("\n  Running CLI equivalent: get-all-bookmarks --limit 2")
+        logger.info("\n  Running CLI equivalent: get-all-bookmarks --limit 2")
         # Assumes KARAKEEP_PYTHON_API_BASE_URL and KARAKEEP_PYTHON_API_KEY are set in env
         subprocess.run(
             "python -m karakeep_python_api get-all-bookmarks --limit 2",
             shell=True,
             check=True,
-            capture_output=True,  # Capture output to avoid printing it during tests unless verbose
+            capture_output=True,  # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
-        print("✓ CLI command executed successfully.")
+        logger.info("✓ CLI command executed successfully.")
     except subprocess.CalledProcessError as e:
-        print(f"  CLI command failed with exit code {e.returncode}")
-        # Print stdout/stderr only if the command failed to aid debugging
-        print(f"  Stdout: {e.stdout}")
-        print(f"  Stderr: {e.stderr}")
+        logger.info(f"  CLI command failed with exit code {e.returncode}")
+        # logger.info stdout/stderr only if the command failed to aid debugging
+        logger.info(f"  Stdout: {e.stdout}")
+        logger.info(f"  Stderr: {e.stderr}")
         pytest.fail(f"CLI command 'get-all-bookmarks --limit 2' failed: {e}")
     except Exception as e:
         pytest.fail(f"An unexpected error occurred running the CLI command: {e}")
@@ -80,7 +81,7 @@ def test_get_all_lists(karakeep_client: KarakeepAPI):
             assert all(
                 isinstance(item, datatypes.ListModel) for item in lists
             ), "All items should be ListModel instances"
-        print(f"✓ Successfully retrieved {len(lists)} lists.")
+        logger.info(f"✓ Successfully retrieved {len(lists)} lists.")
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during list retrieval: {e}")
     except Exception as e:
@@ -88,21 +89,21 @@ def test_get_all_lists(karakeep_client: KarakeepAPI):
 
     # --- Add CLI call ---
     try:
-        print("\n  Running CLI equivalent: get-all-lists")
+        logger.info("\n  Running CLI equivalent: get-all-lists")
         # Assumes KARAKEEP_PYTHON_API_BASE_URL and KARAKEEP_PYTHON_API_KEY are set in env
         subprocess.run(
             "python -m karakeep_python_api get-all-lists",
             shell=True,
             check=True,
-            capture_output=True,  # Capture output to avoid printing it during tests unless verbose
+            capture_output=True,  # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
-        print("✓ CLI command executed successfully.")
+        logger.info("✓ CLI command executed successfully.")
     except subprocess.CalledProcessError as e:
-        print(f"  CLI command failed with exit code {e.returncode}")
-        # Print stdout/stderr only if the command failed to aid debugging
-        print(f"  Stdout: {e.stdout}")
-        print(f"  Stderr: {e.stderr}")
+        logger.info(f"  CLI command failed with exit code {e.returncode}")
+        # logger.info stdout/stderr only if the command failed to aid debugging
+        logger.info(f"  Stdout: {e.stdout}")
+        logger.info(f"  Stderr: {e.stderr}")
         pytest.fail(f"CLI command 'get-all-lists' failed: {e}")
     except Exception as e:
         pytest.fail(f"An unexpected error occurred running the CLI command: {e}")
@@ -117,7 +118,7 @@ def test_get_all_tags(karakeep_client: KarakeepAPI):
             assert all(
                 isinstance(item, datatypes.Tag1) for item in tags
             ), "All items should be Tag1 instances"
-        print(f"✓ Successfully retrieved {len(tags)} tags.")
+        logger.info(f"✓ Successfully retrieved {len(tags)} tags.")
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during tag retrieval: {e}")
     except Exception as e:
@@ -125,21 +126,21 @@ def test_get_all_tags(karakeep_client: KarakeepAPI):
 
     # --- Add CLI call ---
     try:
-        print("\n  Running CLI equivalent: get-all-tags")
+        logger.info("\n  Running CLI equivalent: get-all-tags")
         # Assumes KARAKEEP_PYTHON_API_BASE_URL and KARAKEEP_PYTHON_API_KEY are set in env
         subprocess.run(
             "python -m karakeep_python_api get-all-tags",
             shell=True,
             check=True,
-            capture_output=True,  # Capture output to avoid printing it during tests unless verbose
+            capture_output=True,  # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
-        print("✓ CLI command executed successfully.")
+        logger.info("✓ CLI command executed successfully.")
     except subprocess.CalledProcessError as e:
-        print(f"  CLI command failed with exit code {e.returncode}")
-        # Print stdout/stderr only if the command failed to aid debugging
-        print(f"  Stdout: {e.stdout}")
-        print(f"  Stderr: {e.stderr}")
+        logger.info(f"  CLI command failed with exit code {e.returncode}")
+        # logger.info stdout/stderr only if the command failed to aid debugging
+        logger.info(f"  Stdout: {e.stdout}")
+        logger.info(f"  Stderr: {e.stderr}")
         pytest.fail(f"CLI command 'get-all-tags' failed: {e}")
     except Exception as e:
         pytest.fail(f"An unexpected error occurred running the CLI command: {e}")
@@ -157,23 +158,23 @@ def test_get_all_highlights_paginated(karakeep_client: KarakeepAPI):
             page1.highlights, list
         ), "Highlights attribute should be a list"
         assert len(page1.highlights) <= 3, "Should return at most 'limit' highlights"
-        print(f"✓ Retrieved first page with {len(page1.highlights)} highlights.")
+        logger.info(f"✓ Retrieved first page with {len(page1.highlights)} highlights.")
 
         # If there's a next cursor, get the next page
         if page1.nextCursor:
-            print(f"  Attempting to fetch next page with cursor: {page1.nextCursor}")
+            logger.info(f"  Attempting to fetch next page with cursor: {page1.nextCursor}")
             page2 = karakeep_client.get_all_highlights(limit=3, cursor=page1.nextCursor)
             assert isinstance(page2, datatypes.PaginatedHighlights)
             assert isinstance(page2.highlights, list)
             assert len(page2.highlights) <= 3
-            print(f"✓ Retrieved second page with {len(page2.highlights)} highlights.")
+            logger.info(f"✓ Retrieved second page with {len(page2.highlights)} highlights.")
             # Ensure highlights are different from page 1 (simple check)
             if page1.highlights and page2.highlights:
                 assert (
                     page1.highlights[0].id != page2.highlights[0].id
                 ), "Highlights on page 1 and 2 should differ"
         else:
-            print("  No next cursor found, pagination test ends.")
+            logger.info("  No next cursor found, pagination test ends.")
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during paginated highlight retrieval: {e}")
@@ -184,21 +185,21 @@ def test_get_all_highlights_paginated(karakeep_client: KarakeepAPI):
 
     # --- Add CLI call ---
     try:
-        print("\n  Running CLI equivalent: get-all-highlights --limit 3")
+        logger.info("\n  Running CLI equivalent: get-all-highlights --limit 3")
         # Assumes KARAKEEP_PYTHON_API_BASE_URL and KARAKEEP_PYTHON_API_KEY are set in env
         subprocess.run(
             "python -m karakeep_python_api get-all-highlights --limit 3",
             shell=True,
             check=True,
-            capture_output=True,  # Capture output to avoid printing it during tests unless verbose
+            capture_output=True,  # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
-        print("✓ CLI command executed successfully.")
+        logger.info("✓ CLI command executed successfully.")
     except subprocess.CalledProcessError as e:
-        print(f"  CLI command failed with exit code {e.returncode}")
-        # Print stdout/stderr only if the command failed to aid debugging
-        print(f"  Stdout: {e.stdout}")
-        print(f"  Stderr: {e.stderr}")
+        logger.info(f"  CLI command failed with exit code {e.returncode}")
+        # logger.info stdout/stderr only if the command failed to aid debugging
+        logger.info(f"  Stdout: {e.stdout}")
+        logger.info(f"  Stderr: {e.stderr}")
         pytest.fail(f"CLI command 'get-all-highlights --limit 3' failed: {e}")
     except Exception as e:
         pytest.fail(f"An unexpected error occurred running the CLI command: {e}")
@@ -217,7 +218,7 @@ def test_openapi_spec_accessible(karakeep_client: KarakeepAPI):
         assert (
             "openapi" in spec
         ), "openapi_spec should contain the 'openapi' version key"
-        print(
+        logger.info(
             f"✓ Successfully accessed openapi_spec attribute. Version: {spec.get('openapi', 'N/A')}"
         )
     except Exception as e:
@@ -226,21 +227,21 @@ def test_openapi_spec_accessible(karakeep_client: KarakeepAPI):
     # --- Add CLI call ---
     # The closest CLI equivalent is dumping the spec file content
     try:
-        print("\n  Running CLI equivalent: --dump-openapi-specification")
+        logger.info("\n  Running CLI equivalent: --dump-openapi-specification")
         # This command doesn't require API key or base URL
         subprocess.run(
             "python -m karakeep_python_api --dump-openapi-specification",
             shell=True,
             check=True,
-            capture_output=True,  # Capture output to avoid printing it during tests unless verbose
+            capture_output=True,  # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
-        print("✓ CLI command executed successfully.")
+        logger.info("✓ CLI command executed successfully.")
     except subprocess.CalledProcessError as e:
-        print(f"  CLI command failed with exit code {e.returncode}")
-        # Print stdout/stderr only if the command failed to aid debugging
-        print(f"  Stdout: {e.stdout}")
-        print(f"  Stderr: {e.stderr}")
+        logger.info(f"  CLI command failed with exit code {e.returncode}")
+        # logger.info stdout/stderr only if the command failed to aid debugging
+        logger.info(f"  Stdout: {e.stdout}")
+        logger.info(f"  Stderr: {e.stderr}")
         pytest.fail(f"CLI command '--dump-openapi-specification' failed: {e}")
     except Exception as e:
         pytest.fail(f"An unexpected error occurred running the CLI command: {e}")
@@ -259,12 +260,12 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
         list_name = f"Test List {timestamp}-{random_suffix}"
         list_icon = "🧪"  # Test tube icon
 
-        print(f"\nAttempting to create list: Name='{list_name}', Icon='{list_icon}'")
+        logger.info(f"\nAttempting to create list: Name='{list_name}', Icon='{list_icon}'")
 
         # 2. Get initial list count (optional, for comparison)
         initial_lists = karakeep_client.get_all_lists()
         initial_list_count = len(initial_lists)
-        print(f"  Initial list count: {initial_list_count}")
+        logger.info(f"  Initial list count: {initial_list_count}")
 
         # 3. Create the new list
         create_payload = {"name": list_name, "icon": list_icon, "type": "manual"}
@@ -276,7 +277,7 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
         assert created_list.icon == list_icon, "Created list icon should match"
         assert created_list.id, "Created list must have an ID"
         created_list_id = created_list.id  # Store the ID for deletion
-        print(f"✓ Successfully created list with ID: {created_list_id}")
+        logger.info(f"✓ Successfully created list with ID: {created_list_id}")
 
         # 4. Verify the list appears in get_all_lists
         current_lists_after_create = karakeep_client.get_all_lists()
@@ -286,15 +287,15 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
         assert any(
             lst.id == created_list_id for lst in current_lists_after_create
         ), "Created list should be present in the list of all lists"
-        print(f"  List count after creation: {len(current_lists_after_create)}")
-        print(f"✓ Verified list {created_list_id} is present in get_all_lists.")
+        logger.info(f"  List count after creation: {len(current_lists_after_create)}")
+        logger.info(f"✓ Verified list {created_list_id} is present in get_all_lists.")
 
 
         # 5. Verify the list exists by getting it directly (redundant but good check)
         retrieved_list = karakeep_client.get_a_single_list(list_id=created_list_id)
         assert isinstance(retrieved_list, datatypes.ListModel)
         assert retrieved_list.id == created_list_id
-        print(f"✓ Successfully retrieved the created list by ID.")
+        logger.info(f"✓ Successfully retrieved the created list by ID.")
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during list creation/verification: {e}")
@@ -303,10 +304,10 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
     finally:
         # 6. Delete the list (ensure cleanup even if assertions fail)
         if created_list_id:
-            print(f"\nAttempting to delete list with ID: {created_list_id}")
+            logger.info(f"\nAttempting to delete list with ID: {created_list_id}")
             try:
                 karakeep_client.delete_a_list(list_id=created_list_id)
-                print(f"✓ Successfully deleted list with ID: {created_list_id}")
+                logger.info(f"✓ Successfully deleted list with ID: {created_list_id}")
 
                 # 7. Verify the list is gone by trying to get it (should fail)
                 try:
@@ -318,7 +319,7 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
                     assert (
                         e.status_code == 404
                     ), f"Expected 404 Not Found when getting deleted list, but got status {e.status_code}"
-                    print(
+                    logger.info(
                         f"✓ Confirmed list {created_list_id} is deleted (received 404)."
                     )
 
@@ -330,14 +331,14 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
                 assert not any(
                     lst.id == created_list_id for lst in final_lists
                 ), "Deleted list should not be present in the final list of all lists"
-                print(f"  Final list count: {len(final_lists)}")
+                logger.info(f"  Final list count: {len(final_lists)}")
 
             except (APIError, AuthenticationError) as e:
                 pytest.fail(f"API error during list deletion: {e}")
             except Exception as e:
                 pytest.fail(f"An unexpected error occurred during list deletion: {e}")
         else:
-            print("\nSkipping deletion because list creation failed or ID was not obtained.")
+            logger.info("\nSkipping deletion because list creation failed or ID was not obtained.")
 
 
 def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark):
@@ -351,7 +352,7 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
 
     try:
         # 1. Bookmark is already created by the 'managed_bookmark' fixture.
-        print(f"\nUsing managed bookmark ID: {created_bookmark_id}, URL: '{test_url}', Title: '{original_title}'")
+        logger.info(f"\nUsing managed bookmark ID: {created_bookmark_id}, URL: '{test_url}', Title: '{original_title}'")
 
         # 2. Verify the bookmark exists by getting it directly
         retrieved_bookmark = karakeep_client.get_a_single_bookmark(
@@ -361,7 +362,7 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
         assert retrieved_bookmark.id == created_bookmark_id
         assert retrieved_bookmark.content.url == test_url
         assert retrieved_bookmark.title == original_title
-        print(f"✓ Successfully retrieved the managed bookmark by ID.")
+        logger.info(f"✓ Successfully retrieved the managed bookmark by ID.")
 
 
         # 3. Search for the created bookmark
@@ -374,10 +375,16 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
         # waiting a bit for the indexation just in case
         time.sleep(30)
 
-        search_query_component = original_title.split(" ")[0] + " " + original_title.split(" ")[1]
-        print(f"\nAttempting to search for bookmark with query based on title: '{search_query_component}'. Retrying multiple times because search is nondeterministic.")
-        
-        for trial in range(5):
+        search_queries = [
+            "Managed Fixture Bookmark",
+            "managed fixture bookmark",
+            "managed fixture",
+            "fixture managed",
+            "fixture",
+            '"fixture"',
+        ]
+        for trial, search_query_component in enumerate(search_queries):
+            logger.info(f"\nAttempting to search for bookmark with query based on title: '{search_query_component}'. Retrying multiple times because search is nondeterministic.")
             search_results = karakeep_client.search_bookmarks(q=search_query_component, limit=100, include_content=False)
             assert isinstance(
                 search_results, datatypes.PaginatedBookmarks
@@ -393,11 +400,11 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
             else:
                 time.sleep(3)
         assert found_in_search, \
-        f"Managed bookmark {created_bookmark_id} (Title: '{original_title}') not found in {trial} different search results for '{search_query_component}'. Titles were: '{titles_in_search}'."
-        print(f"✓ Found managed bookmark in search results for '{search_query_component}'.")
+        f"Managed bookmark {created_bookmark_id} (Title: '{original_title}') not found in {trial + 1} different search results for '{search_query_component}'. Titles were: '{titles_in_search}'."
+        logger.info(f"✓ Found managed bookmark in search results for '{search_query_component}'.")
 
         # 4. Test CLI search equivalent
-        print(f"\n  Running CLI equivalent: search-bookmarks --q '{search_query_component}' --limit 10 --include-content false")
+        logger.info(f"\n  Running CLI equivalent: search-bookmarks --q '{search_query_component}' --limit 10 --include-content false")
         try:
             cli_search_command = f"python -m karakeep_python_api search-bookmarks --q '{search_query_component}' --limit 10 --include-content false"
             search_cli_output = subprocess.run(
@@ -409,11 +416,11 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
             )
             assert created_bookmark_id in search_cli_output.stdout, \
                 f"Managed bookmark ID {created_bookmark_id} not found in CLI search output for '{search_query_component}'"
-            print("✓ CLI search command executed successfully and contained the bookmark ID.")
+            logger.info("✓ CLI search command executed successfully and contained the bookmark ID.")
         except subprocess.CalledProcessError as e:
-            print(f"  CLI search command failed with exit code {e.returncode}")
-            print(f"  Stdout: {e.stdout}")
-            print(f"  Stderr: {e.stderr}")
+            logger.info(f"  CLI search command failed with exit code {e.returncode}")
+            logger.info(f"  Stdout: {e.stdout}")
+            logger.info(f"  Stderr: {e.stderr}")
             pytest.fail(f"CLI command 'search-bookmarks --q \"{search_query_component}\"' failed: {e}")
         except Exception as e:
             pytest.fail(f"An unexpected error occurred running the CLI search command: {e}")
@@ -439,10 +446,10 @@ def test_update_bookmark_title(karakeep_client: KarakeepAPI, managed_bookmark: d
     try:
         # The bookmark is already created by the 'managed_bookmark' fixture.
         # We have its ID in created_bookmark_id and its original title.
-        print(f"\nUsing managed bookmark ID: {created_bookmark_id}, Original Title: '{original_title}'")
+        logger.info(f"\nUsing managed bookmark ID: {created_bookmark_id}, Original Title: '{original_title}'")
 
         # 1. Update the bookmark's title using the API client
-        print(f"\nAttempting to update bookmark ID {created_bookmark_id} title to: '{target_api_title}' via API")
+        logger.info(f"\nAttempting to update bookmark ID {created_bookmark_id} title to: '{target_api_title}' via API")
         update_payload_api = {"title": target_api_title}
         updated_bookmark_partial = karakeep_client.update_a_bookmark(
             bookmark_id=created_bookmark_id, update_data=update_payload_api
@@ -450,20 +457,20 @@ def test_update_bookmark_title(karakeep_client: KarakeepAPI, managed_bookmark: d
         assert isinstance(updated_bookmark_partial, dict), "Update response should be a dict"
         assert updated_bookmark_partial.get("title") == target_api_title, \
             f"Partial response title '{updated_bookmark_partial.get('title')}' does not match target API title '{target_api_title}'"
-        print(f"✓ API call to update_a_bookmark successful. Partial response title: '{updated_bookmark_partial.get('title')}'")
+        logger.info(f"✓ API call to update_a_bookmark successful. Partial response title: '{updated_bookmark_partial.get('title')}'")
 
         # 2. Verify the API update by fetching the bookmark again
-        print(f"\nFetching bookmark ID {created_bookmark_id} to verify API title update.")
+        logger.info(f"\nFetching bookmark ID {created_bookmark_id} to verify API title update.")
         retrieved_bookmark_after_api_update = karakeep_client.get_a_single_bookmark(
             bookmark_id=created_bookmark_id
         )
         assert isinstance(retrieved_bookmark_after_api_update, datatypes.Bookmark)
         assert retrieved_bookmark_after_api_update.title == target_api_title, \
             f"Retrieved bookmark title '{retrieved_bookmark_after_api_update.title}' does not match expected API-updated title '{target_api_title}'"
-        print(f"✓ Successfully verified bookmark title updated by API to: '{retrieved_bookmark_after_api_update.title}'")
+        logger.info(f"✓ Successfully verified bookmark title updated by API to: '{retrieved_bookmark_after_api_update.title}'")
 
         # 3. Test CLI equivalent for updating the bookmark's title
-        print(f"\n  Running CLI equivalent to update title to: '{target_cli_title}'")
+        logger.info(f"\n  Running CLI equivalent to update title to: '{target_cli_title}'")
         cli_update_payload_json = json.dumps({"title": target_cli_title})
         # Ensure the JSON string is properly quoted for the shell command
         cli_update_command = f"python -m karakeep_python_api update-a-bookmark --bookmark-id {created_bookmark_id} --update-data '{cli_update_payload_json}'"
@@ -476,23 +483,23 @@ def test_update_bookmark_title(karakeep_client: KarakeepAPI, managed_bookmark: d
                 capture_output=True,
                 text=True,
             )
-            print("✓ CLI update command executed successfully.")
+            logger.info("✓ CLI update command executed successfully.")
 
             # 4. Verify CLI update by fetching the bookmark again
-            print(f"\nFetching bookmark ID {created_bookmark_id} to verify CLI title update.")
+            logger.info(f"\nFetching bookmark ID {created_bookmark_id} to verify CLI title update.")
             retrieved_bookmark_after_cli_update = karakeep_client.get_a_single_bookmark(
                 bookmark_id=created_bookmark_id
             )
             assert isinstance(retrieved_bookmark_after_cli_update, datatypes.Bookmark)
             assert retrieved_bookmark_after_cli_update.title == target_cli_title, \
                 f"Retrieved bookmark title '{retrieved_bookmark_after_cli_update.title}' after CLI update does not match expected '{target_cli_title}'"
-            print(f"✓ Successfully verified bookmark title updated by CLI to: '{retrieved_bookmark_after_cli_update.title}'")
+            logger.info(f"✓ Successfully verified bookmark title updated by CLI to: '{retrieved_bookmark_after_cli_update.title}'")
 
         except subprocess.CalledProcessError as e:
-            print(f"  CLI update command failed with exit code {e.returncode}")
-            print(f"  Command: {cli_update_command}")
-            print(f"  Stdout: {e.stdout}")
-            print(f"  Stderr: {e.stderr}")
+            logger.info(f"  CLI update command failed with exit code {e.returncode}")
+            logger.info(f"  Command: {cli_update_command}")
+            logger.info(f"  Stdout: {e.stdout}")
+            logger.info(f"  Stderr: {e.stderr}")
             pytest.fail(f"CLI command for update-a-bookmark failed: {e}")
         except Exception as e:
             pytest.fail(f"An unexpected error occurred running the CLI update command: {e}")
@@ -518,7 +525,7 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
 
     try:
         # 1. Attach a new tag by name to the bookmark
-        print(f"\nAttempting to attach tag '{initial_tag_name}' to bookmark {bookmark_id}")
+        logger.info(f"\nAttempting to attach tag '{initial_tag_name}' to bookmark {bookmark_id}")
         attach_payload = {"tags": [{"tagName": initial_tag_name}]}
         attach_response = karakeep_client.attach_tags_to_a_bookmark(
             bookmark_id=bookmark_id, tags_data=attach_payload
@@ -527,10 +534,10 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
             "Failed to attach tag or response format incorrect"
         tag_id_to_manage = attach_response["attached"][0]
         assert isinstance(tag_id_to_manage, str), "Attached tag ID should be a string"
-        print(f"✓ Tag '{initial_tag_name}' attached with ID: {tag_id_to_manage}")
+        logger.info(f"✓ Tag '{initial_tag_name}' attached with ID: {tag_id_to_manage}")
 
         # 2. Update the tag's name
-        print(f"\nAttempting to update tag {tag_id_to_manage} to name '{updated_tag_name}'")
+        logger.info(f"\nAttempting to update tag {tag_id_to_manage} to name '{updated_tag_name}'")
         update_payload = {"name": updated_tag_name}
         updated_tag = karakeep_client.update_a_tag(
             tag_id=tag_id_to_manage, update_data=update_payload
@@ -538,27 +545,27 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
         # Do not check the type because karakeep 0.24.1 has a server side bug
         # assert isinstance(updated_tag, datatypes.Tag1), "Update tag response should be Tag1 model"
         # assert updated_tag.name == updated_tag_name, "Tag name was not updated as expected"
-        # print(f"✓ Tag {tag_id_to_manage} updated to name '{updated_tag.name}'")
+        # logger.info(f"✓ Tag {tag_id_to_manage} updated to name '{updated_tag.name}'")
         assert updated_tag["name"] == updated_tag_name, "Tag name was not updated as expected"
-        print(f"✓ Tag {tag_id_to_manage} updated to name '{updated_tag['name']}'")
+        logger.info(f"✓ Tag {tag_id_to_manage} updated to name '{updated_tag['name']}'")
 
         # 3. Verify tag update by getting it directly
-        print(f"\nFetching tag {tag_id_to_manage} to verify its name is '{updated_tag_name}'")
+        logger.info(f"\nFetching tag {tag_id_to_manage} to verify its name is '{updated_tag_name}'")
         retrieved_tag = karakeep_client.get_a_single_tag(tag_id=tag_id_to_manage)
         assert isinstance(retrieved_tag, datatypes.Tag1), "Get single tag response should be Tag1 model"
         assert retrieved_tag.name == updated_tag_name, "Retrieved tag name does not match updated name"
         assert retrieved_tag.id == tag_id_to_manage, "Retrieved tag ID does not match"
-        print(f"✓ Verified tag {tag_id_to_manage} has name '{retrieved_tag.name}'")
+        logger.info(f"✓ Verified tag {tag_id_to_manage} has name '{retrieved_tag.name}'")
 
         # 4. Detach the tag from the bookmark
-        print(f"\nAttempting to detach tag {tag_id_to_manage} from bookmark {bookmark_id}")
+        logger.info(f"\nAttempting to detach tag {tag_id_to_manage} from bookmark {bookmark_id}")
         detach_payload = {"tags": [{"tagId": tag_id_to_manage}]}
         detach_response = karakeep_client.detach_tags_from_a_bookmark(
             bookmark_id=bookmark_id, tags_data=detach_payload
         )
         assert "detached" in detach_response and tag_id_to_manage in detach_response["detached"], \
             "Failed to detach tag or response format incorrect"
-        print(f"✓ Tag {tag_id_to_manage} detached from bookmark {bookmark_id}")
+        logger.info(f"✓ Tag {tag_id_to_manage} detached from bookmark {bookmark_id}")
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during tag lifecycle test: {e}")
@@ -567,10 +574,10 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
     finally:
         # 5. Delete the tag (ensure cleanup even if assertions fail mid-test)
         if tag_id_to_manage:
-            print(f"\nAttempting to delete tag {tag_id_to_manage} (cleanup)")
+            logger.info(f"\nAttempting to delete tag {tag_id_to_manage} (cleanup)")
             try:
                 karakeep_client.delete_a_tag(tag_id=tag_id_to_manage)
-                print(f"✓ Successfully deleted tag {tag_id_to_manage}")
+                logger.info(f"✓ Successfully deleted tag {tag_id_to_manage}")
 
                 # 6. Verify the tag is gone by trying to get it (should fail with 404)
                 try:
@@ -581,14 +588,14 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
                 except APIError as e:
                     assert e.status_code == 404, \
                         f"Expected 404 Not Found when getting deleted tag, but got status {e.status_code}"
-                    print(f"✓ Confirmed tag {tag_id_to_manage} is deleted (received 404).")
+                    logger.info(f"✓ Confirmed tag {tag_id_to_manage} is deleted (received 404).")
             except (APIError, AuthenticationError) as e:
                 # Log error during cleanup but don't let it mask original test failure
-                print(f"  API error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}")
+                logger.info(f"  API error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}")
             except Exception as e:
-                print(f"  Unexpected error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}")
+                logger.info(f"  Unexpected error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}")
         else:
-            print("\nSkipping tag deletion (cleanup) because tag_id was not obtained or test failed before creation.")
+            logger.info("\nSkipping tag deletion (cleanup) because tag_id was not obtained or test failed before creation.")
 
 
 # --- Test User Info/Stats Endpoints ---
@@ -609,7 +616,7 @@ def test_get_current_user_stats(karakeep_client: KarakeepAPI):
         assert isinstance(stats["numLists"], int) and stats["numLists"] >= 0
         assert isinstance(stats["numTags"], int) and stats["numTags"] >= 0
 
-        print(f"✓ Successfully retrieved user stats: {stats}")
+        logger.info(f"✓ Successfully retrieved user stats: {stats}")
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during user stats retrieval: {e}")
@@ -618,21 +625,21 @@ def test_get_current_user_stats(karakeep_client: KarakeepAPI):
 
     # --- Add CLI call ---
     try:
-        print("\n  Running CLI equivalent: get-current-user-stats")
+        logger.info("\n  Running CLI equivalent: get-current-user-stats")
         # Assumes KARAKEEP_PYTHON_API_BASE_URL and KARAKEEP_PYTHON_API_KEY are set in env
         subprocess.run(
             "python -m karakeep_python_api get-current-user-stats",
             shell=True,
             check=True,
-            capture_output=True, # Capture output to avoid printing it during tests unless verbose
+            capture_output=True, # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
-        print("✓ CLI command executed successfully.")
+        logger.info("✓ CLI command executed successfully.")
     except subprocess.CalledProcessError as e:
-        print(f"  CLI command failed with exit code {e.returncode}")
-        # Print stdout/stderr only if the command failed to aid debugging
-        print(f"  Stdout: {e.stdout}")
-        print(f"  Stderr: {e.stderr}")
+        logger.info(f"  CLI command failed with exit code {e.returncode}")
+        # logger.info stdout/stderr only if the command failed to aid debugging
+        logger.info(f"  Stdout: {e.stdout}")
+        logger.info(f"  Stderr: {e.stderr}")
         pytest.fail(f"CLI command 'get-current-user-stats' failed: {e}")
     except Exception as e:
         pytest.fail(f"An unexpected error occurred running the CLI command: {e}")
